AccessPoint

Struct AccessPoint 

pub struct AccessPoint {
Show 13 fields pub flags: Property<NM80211ApFlags>, pub wpa_flags: Property<NM80211ApSecurityFlags>, pub rsn_flags: Property<NM80211ApSecurityFlags>, pub ssid: Property<Ssid>, pub frequency: Property<u32>, pub bssid: Property<NetworkIdentifier>, pub mode: Property<NM80211Mode>, pub max_bitrate: Property<u32>, pub bandwidth: Property<u32>, pub strength: Property<u8>, pub last_seen: Property<i32>, pub security: Property<SecurityType>, pub is_hidden: Property<bool>, /* private fields */
}
WiFi access point representation.

Provides information about a detected WiFi access point including its security configuration, signal strength, frequency, and identification. Access points are discovered and monitored through the WiFi device interface.

Fields

flags: Property<NM80211ApFlags>

Flags describing the capabilities of the access point. See NM80211ApFlags.

wpa_flags: Property<NM80211ApSecurityFlags>

Flags describing the access point’s capabilities according to WPA (Wifi Protected Access). See NM80211ApSecurityFlags.

rsn_flags: Property<NM80211ApSecurityFlags>

Flags describing the access point’s capabilities according to the RSN (Robust Secure Network) protocol. See NM80211ApSecurityFlags.

ssid: Property<Ssid>

The Service Set Identifier identifying the access point. The Ssid is a binary array to support non-UTF-8 Ssids.

frequency: Property<u32>

The radio channel frequency in use by the access point, in MHz.

bssid: Property<NetworkIdentifier>

The hardware address (Bssid) of the access point.

mode: Property<NM80211Mode>

Describes the operating mode of the access point.

max_bitrate: Property<u32>

The maximum bitrate this access point is capable of, in kilobits/second (Kb/s).

bandwidth: Property<u32>

The bandwidth announced by the access point in MHz.

strength: Property<u8>

The current signal quality of the access point, in percent.

last_seen: Property<i32>

The timestamp (in CLOCK_BOOTTIME seconds) for the last time the access point was found in scan results. A value of -1 means the access point has never been found in scan results.

security: Property<SecurityType>

Simplified security type derived from flags.

Provides a user-friendly classification of the AP’s security.

is_hidden: Property<bool>

Whether this is a hidden network (non-broadcasting Ssid).

Implementations

Source

impl AccessPoint

pub fn object_path(&self) -> &OwnedObjectPath

Returns the D-Bus object path for this access point.