ActiveConnection

Struct ActiveConnection 

pub struct ActiveConnection {
Show 17 fields pub object_path: OwnedObjectPath, pub connection_path: Property<OwnedObjectPath>, pub specific_object: Property<OwnedObjectPath>, pub id: Property<String>, pub uuid: Property<String>, pub type_: Property<String>, pub devices: Property<Vec<OwnedObjectPath>>, pub state: Property<NMActiveConnectionState>, pub state_flags: Property<NMActivationStateFlags>, pub default: Property<bool>, pub ip4_config: Property<OwnedObjectPath>, pub dhcp4_config: Property<OwnedObjectPath>, pub default6: Property<bool>, pub ip6_config: Property<OwnedObjectPath>, pub dhcp6_config: Property<OwnedObjectPath>, pub vpn: Property<bool>, pub controller: Property<OwnedObjectPath>, /* private fields */
}
Active network connection in NetworkManager.

Tracks state and configuration of currently active connections, including devices, IP configuration, and connection properties. Properties update reactively as connection state changes.

Fields

object_path: OwnedObjectPath

Object path for this connection

connection_path: Property<OwnedObjectPath>

The path of the connection object that this ActiveConnection is using.

specific_object: Property<OwnedObjectPath>

Specific object associated with the active connection. Reflects the object used during connection activation, and will not change over the lifetime of the ActiveConnection once set.

id: Property<String>

The ID of the connection, provided for convenience.

uuid: Property<String>

The UUID of the connection, provided for convenience.

type_: Property<String>

The type of the connection, provided for convenience.

devices: Property<Vec<OwnedObjectPath>>

Array of object paths representing devices which are part of this active connection.

state: Property<NMActiveConnectionState>

The state of this active connection.

state_flags: Property<NMActivationStateFlags>

The state flags of this active connection. See NMActivationStateFlags.

default: Property<bool>

Whether this active connection is the default IPv4 connection, i.e. whether it currently owns the default IPv4 route.

ip4_config: Property<OwnedObjectPath>

Object path of the Ip4Config object describing the configuration of the connection. Only valid when the connection is in the NM_ACTIVE_CONNECTION_STATE_ACTIVATED state.

dhcp4_config: Property<OwnedObjectPath>

Object path of the Dhcp4Config object describing the DHCP options returned by the DHCP server (assuming the connection used DHCP). Only valid when the connection is in the NM_ACTIVE_CONNECTION_STATE_ACTIVATED state.

default6: Property<bool>

Whether this active connection is the default IPv6 connection, i.e. whether it currently owns the default IPv6 route.

ip6_config: Property<OwnedObjectPath>

Object path of the Ip6Config object describing the configuration of the connection. Only valid when the connection is in the NM_ACTIVE_CONNECTION_STATE_ACTIVATED state.

dhcp6_config: Property<OwnedObjectPath>

Object path of the Dhcp6Config object describing the DHCP options returned by the DHCP server (assuming the connection used DHCP). Only valid when the connection is in the NM_ACTIVE_CONNECTION_STATE_ACTIVATED state.

vpn: Property<bool>

Whether this active connection is also a VPN connection.

controller: Property<OwnedObjectPath>

The path to the controller device if the connection is a port.

Implementations

Source

impl ActiveConnection

pub async fn active_connection_state_changed_signal( &self, ) -> Result<impl Stream<Item = ActiveConnectionStateChangedEvent>, Error>

Emitted when the active connection changes state.

Errors

Returns error if D-Bus proxy creation fails.

pub async fn vpn_connection_state_changed_signal( &self, ) -> Result<impl Stream<Item = VpnConnectionStateChangedEvent>, Error>

Emitted when the state of the VPN connection has changed.

Errors

Returns error if D-Bus proxy creation fails.